Enum Event
#[non_exhaustive]pub enum Event<'a> {
Title {
title: String,
},
AppId {
app_id: String,
},
OutputEnter {
output: WlOutput,
},
OutputLeave {
output: WlOutput,
},
State {
state: Vec<u8>,
},
Done,
Closed,
Parent {
parent: Option<ZwlrForeignToplevelHandleV1>,
},
}wayland and Linux only.Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Title
title change
This event is emitted whenever the title of the toplevel changes.
AppId
app-id change
This event is emitted whenever the app-id of the toplevel changes.
OutputEnter
toplevel entered an output
This event is emitted whenever the toplevel becomes visible on the given output. A toplevel may be visible on multiple outputs.
Fields
output: WlOutputOutputLeave
toplevel left an output
This event is emitted whenever the toplevel stops being visible on the given output. It is guaranteed that an entered-output event with the same output has been emitted before this event.
Fields
output: WlOutputState
the toplevel state changed
This event is emitted immediately after the zlw_foreign_toplevel_handle_v1 is created and each time the toplevel state changes, either because of a compositor action or because of a request in this protocol.
Done
all information about the toplevel has been sent
This event is sent after all changes in the toplevel state have been sent.
This allows changes to the zwlr_foreign_toplevel_handle_v1 properties to be seen as atomic, even if they happen via multiple events.
Closed
this toplevel has been destroyed
This event means the toplevel has been destroyed. It is guaranteed there won’t be any more events for this zwlr_foreign_toplevel_handle_v1. The toplevel itself becomes inert so any requests will be ignored except the destroy request.
Parent
parent change
This event is emitted whenever the parent of the toplevel changes.
No event is emitted when the parent handle is destroyed by the client.
Only available since version 3 of the interface
Fields
parent: Option<ZwlrForeignToplevelHandleV1>Implementations