Struct ZwlrForeignToplevelHandleV1
pub struct ZwlrForeignToplevelHandleV1 { /* private fields */ }wayland and Linux only.Expand description
an opened toplevel
A zwlr_foreign_toplevel_handle_v1 object represents an opened toplevel window. Each app may have multiple opened toplevels.
Each toplevel has a list of outputs it is visible on, conveyed to the client with the output_enter and output_leave events.
See also the Request enum for this interface.
Implementations
impl ZwlrForeignToplevelHandleV1
impl ZwlrForeignToplevelHandleV1
pub fn title(&self, title: String)
pub fn title(&self, title: String)
title change
This event is emitted whenever the title of the toplevel changes.
pub fn app_id(&self, app_id: String)
pub fn app_id(&self, app_id: String)
app-id change
This event is emitted whenever the app-id of the toplevel changes.
pub fn output_enter(&self, output: &WlOutput)
pub fn output_enter(&self, output: &WlOutput)
toplevel entered an output
This event is emitted whenever the toplevel becomes visible on the given output. A toplevel may be visible on multiple outputs.
pub fn output_leave(&self, output: &WlOutput)
pub fn output_leave(&self, output: &WlOutput)
toplevel left an output
This event is emitted whenever the toplevel stops being visible on the given output. It is guaranteed that an entered-output event with the same output has been emitted before this event.
pub fn state(&self, state: Vec<u8>)
pub fn state(&self, state: Vec<u8>)
the toplevel state changed
This event is emitted immediately after the zlw_foreign_toplevel_handle_v1 is created and each time the toplevel state changes, either because of a compositor action or because of a request in this protocol.
pub fn done(&self)
pub fn done(&self)
all information about the toplevel has been sent
This event is sent after all changes in the toplevel state have been sent.
This allows changes to the zwlr_foreign_toplevel_handle_v1 properties to be seen as atomic, even if they happen via multiple events.
pub fn closed(&self)
pub fn closed(&self)
this toplevel has been destroyed
This event means the toplevel has been destroyed. It is guaranteed there won’t be any more events for this zwlr_foreign_toplevel_handle_v1. The toplevel itself becomes inert so any requests will be ignored except the destroy request.
pub fn parent(&self, parent: Option<&ZwlrForeignToplevelHandleV1>)
pub fn parent(&self, parent: Option<&ZwlrForeignToplevelHandleV1>)
parent change
This event is emitted whenever the parent of the toplevel changes.
No event is emitted when the parent handle is destroyed by the client.